@@ -28,7 +28,7 @@ def parse_hidden(output):
             l_split = out.split("lookup:")
 
             r = requests.get(
-                daisi_base_url + "/pickle?lookup=" + l_split[1], headers=headers
+                sandy_base_url + "/pickle?lookup=" + l_split[1], headers=headers
             )
 
             out = load_pickle_string(r.content.decode())
@@ -60,7 +60,7 @@ class Daisi:
         self.uuid = None
         self.name = None
         self.description = None
-        self.base_url = sandy_base_url + "/pebble-cli-api/pebbles"
+        self.base_url = base_url + "/pebble-cli-api/pebbles"
 
         if not daisi_id:
             self.name = self.random_name()
@@ -82,6 +82,7 @@ class Daisi:
                 self.name = r.json()["name"]
                 self.uuid = daisi_id
         else:
+            print("Calling " + self.base_url + "/search?query=" + daisi_id)
             r = requests.get(
                 self.base_url + "/search?query=" + daisi_id, headers=headers
             )
@@ -117,16 +118,19 @@ class Daisi:
             if type(argument_value) == list:
 
                 # Assume it's the first output
-                clean_args[argument_name] = argument_value[0]["data"]
+                try:
+                    clean_args[argument_name] = argument_value[0]["data"]
 
-                # Check whether the ids of outputs match
-                for arg in argument_value:
+                    # Check whether the ids of outputs match
+                    for arg in argument_value:
 
-                    # If the id of a particular output matches the argument name, set the value
-                    if arg["id"].startswith(argument_name) or argument_name.startswith(
-                        arg["id"]
-                    ):
-                        clean_args[argument_name] = arg["data"]
+                        # If the id of a particular output matches the argument name, set the value
+                        if arg["id"].startswith(argument_name) or argument_name.startswith(
+                            arg["id"]
+                        ):
+                            clean_args[argument_name] = arg["data"]
+                except:
+                    continue
 
         return clean_args
 
